@@ -51,6 +51,12 @@ class CustomRule(object):
         self.group_b = group_b
         self.comparison = comparison or default_comparison
 
+    def __repr__(self):
+        import inspect as i
+        return f"{i.getsource(self.group_a)}" \
+               f"{i.getsource(self.group_b)}" \
+               f"{i.getsource(self.comparison)}"
+
 
 class OptimizerSettings(object):
 
